pub struct Archivist { /* private fields */ }Expand description
Responsible for initializing an Archivist instance. Supports multiple configurations by
either calling or not calling methods on the builder like serve_test_controller_protocol.
Implementations
Sourceimpl Archivist
impl Archivist
Sourcepub async fn new(ring_buffer: Reader, config: Config) -> Self
pub async fn new(ring_buffer: Reader, config: Config) -> Self
Creates new instance, sets up inspect and adds ‘archive’ directory to output folder.
Also installs fuchsia.diagnostics.Archive service.
Call install_log_services
pub async fn initialize_external_event_sources( event_router: &mut EventRouter, scope: &Scope, )
Sourcepub async fn run(
self,
fs: ServiceFs<ServiceObj<'static, ()>>,
is_embedded: bool,
store: CapabilityStoreProxy,
request_stream: LifecycleRequestStream,
) -> Result<(), Error>
pub async fn run( self, fs: ServiceFs<ServiceObj<'static, ()>>, is_embedded: bool, store: CapabilityStoreProxy, request_stream: LifecycleRequestStream, ) -> Result<(), Error>