EventProducer

Trait EventProducer 

pub trait EventProducer {
    // Required method
    fn set_dispatcher(&mut self, dispatcher: Dispatcher);
}
Trait implemented by data types which emit events.

Required Methods

fn set_dispatcher(&mut self, dispatcher: Dispatcher)

Whent registered, event producers will receive a call on this method with the dispatcher they can use to emit events.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors