DebugLog

Trait DebugLog 

pub trait DebugLog {
    // Required methods
    fn read(&self) -> Result<DebugLogRecord, Status>;
    fn ready_signal(&self) -> impl Future<Output = Result<(), Status>> + Send;
}

Required Methods

fn read(&self) -> Result<DebugLogRecord, Status>

Reads a single entry off the debug log into buffer. Any existing contents in buffer are overwritten.

fn ready_signal(&self) -> impl Future<Output = Result<(), Status>> + Send

Returns a future that completes when there is another log to read.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors